Error

Enum Error 

pub enum Error {
    Incomplete,
    BadOffset(usize),
    BadInput {
        err: &'static str,
    },
}
The error type for the byte crate.

  • Error::BadOffset will be returned when the offset parameter exceeds the slice’s length.

  • Error::BadInput and Error::Incomplete will be returned when try_read() or try_write() finds the bytes are invalid or not long enough to determine their validity.

Note that we usually use bytes.read() in try_read() which may return Error::BadOffset, indicating incomplete data. So the error will automatically be converted into Error::Incomplete if you use bytes.read() (the same applies to write()).

Variants



Incomplete

The requested data is bigger than the available range



BadOffset(usize)

The offset is invalid



BadInput

The requested data content is invalid

Fields

err: &'static str